@@ -1,6 +1,6 @@
 package Enbld::Error;
 
-use 5.012;
+use strict;
 use warnings;
 
 use overload (
